@@ -24,14 +24,18 @@ class Network3Medusa():
             first = True
             for interface in json_dict['TABLE_interface']['ROW_interface']:
                 if first:
-                    print(interface)
                     first = False
                     raw_json=interface
-                    self.add_file_to_hedera(str(raw_json))
-                else:
-                    print(interface)
+                    print("first")
+                    self.add_file_to_hedera(f"{ str(raw_json) },")
+                elif json_dict['TABLE_interface']['ROW_interface'][-1]:
                     raw_json=interface
+                    print("last")
                     self.append_file_to_hedera(str(raw_json))
+                else:
+                    raw_json=interface
+                    print("middle")
+                    self.append_file_to_hedera(f"{ str(raw_json) },")
 
             query = FileInfoQuery().setFileId(self.fileId)
             info = query.execute(self.client)
